@@ -15,42 +15,35 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""
-Viewer for NFO files.
+"""Viewer for NFO files."""
 
-:var __version__: Version number as string in format ``MAJOR.MINOR[.PATCH]``
-:var CONFIG_HOME_DIR: Path to user's local configuration directory
-:var DATA_DIR: Path to the global data directory
-:var LOCALE_DIR: Path to the global locale directory
-:var conf: Instance of :class:`ConfigurationStore` used
-"""
+__version__ = "1.17"
 
-__version__ = "1.14"
-
-import os
+import gi
+gi.require_version("Gdk", "3.0")
+gi.require_version("Gtk", "3.0")
 
 from nfoview.paths import *
-from gi.repository import Gtk
-icon_theme = Gtk.IconTheme.get_default()
-path = os.path.join(DATA_DIR, "icons")
-icon_theme.append_search_path(os.path.abspath(path))
-
 from nfoview import i18n
 from nfoview import util
 from nfoview.errors import *
 from nfoview.config import *
-
-conf = ConfigurationStore()
-conf.read_from_file()
-
-from nfoview.schemes import *
+conf = ConfigurationStore(read=True)
+from nfoview import schemes
 from nfoview.builder import *
 from nfoview.about import *
 from nfoview.open import *
 from nfoview.preferences import *
 from nfoview.export import *
 from nfoview.view import *
+from nfoview.action import *
 from nfoview import actions
 from nfoview.window import *
-from nfoview import main
+from nfoview.application import *
 from nfoview.unittest import *
+
+def main(paths):
+    """Initialize application."""
+    global app
+    app = Application(paths)
+    raise SystemExit(app.run())
